Name:       fcgiwrap
Version:    1.1.0
Release:    2%{?dist}
Summary:    Simple FastCGI wrapper for CGI scripts
Group:      System Environment/Daemons
License:    BSD-like
URL:        http://nginx.localdomain.pl/wiki/FcgiWrap
Source0:    %{name}-%{version}.tgz
BuildRequires:  autoconf automake fcgi-devel
Requires:   fcgi

BuildRequires:   systemd
Requires(post):    systemd
Requires(preun):   systemd

%description
This package provides a simple FastCGI wrapper for CGI scripts with/
following features:
 - very lightweight (84KB of private memory per instance)
 - fixes broken CR/LF in headers
 - handles environment in a sane way (CGI scripts get HTTP-related env.
   vars from FastCGI parameters and inherit all the others from
   environment of fcgiwrap )
 - no configuration, so you can run several sites off the same
   fcgiwrap pool
 - passes CGI stderr output to stderr stream of cgiwrap or FastCGI
 - support systemd socket activation, launcher program like spawn-fcgi
   is no longer required on systemd-enabled distributions


%prep
%setup -q


%build
autoreconf -i
%configure
make %{?_smp_mflags}


%install
%{__rm} -rf %{buildroot}
make install DESTDIR=%{buildroot}


install -d %{buildroot}%{_unitdir}
install -d -p -m 755 %{buildroot}/var/run/%{name}
%{__cat} << EOF > %{buildroot}%{_unitdir}/%{name}.service
[Unit]
Description=Simple CGI Server
After=nss-user-lookup.target

[Service]
Type=simple
Environment='fcgi_sock=/var/run/%{name}/%{name}.sock'
ExecStartPre=-/bin/sh -c 'if [ -e \${fcgi_sock} ]; then /bin/rm \${fcgi_sock}; fi'
ExecStart=%{_sbindir}/fcgiwrap -f -s unix:\${fcgi_sock}
User=
Group=

[Install]
WantedBy=multi-user.target
EOF
%{__chmod} 0644 %{buildroot}%{_unitdir}/%{name}.service

%files
%defattr(-,root,root)
%{_sbindir}/fcgiwrap
%doc README.rst
%{_mandir}/man8/fcgiwrap.8*


%package systemd-selinux
Summary: Systemd spawner for %{name} with SELinux support
Group: System Environment/Daemons
Requires: %{name} = %{version}-%{release}
Requires: systemd selinux-policy
Requires(post): policycoreutils-python
Requires(postun): policycoreutils-python
%description systemd-selinux
%{name} configuration files for spawn fcgi with systemd ang SELinux support.

%post systemd-selinux
semanage fcontext -a -t httpd_var_run_t '/var/run/%{name}(/.*)?' 2>/dev/null
restorecon -R /var/run/%{name}

%postun systemd-selinux
if [ $1 -eq 0 ] ; then
semanage fcontext -d -t httpd_var_run_t '/var/run/%{name}(/.*)?' 2>/dev/null
fi

%files systemd-selinux
%defattr(-,root,root)
%{_unitdir}/%{name}.service
%dir /var/run/%{name}


%package systemd-nginx
Summary: Systemd spawner for %{name} with nginx support
Group: System Environment/Daemons
Requires: %{name} = %{version}-%{release}
Requires: nginx systemd %{name}-systemd-selinux
%description systemd-nginx
%{name} configuration files for spawn fcgi in systemd with nginx installed.

%files systemd-nginx
%defattr(-,root,root)

%post systemd-nginx
sed -i 's/^.*User=.*$/User=nginx/' %{_unitdir}/%{name}.service
sed -i 's/^.*Group=.*$/Group=nginx/' %{_unitdir}/%{name}.service
systemctl daemon-reload
chown -R nginx:nginx /var/run/%{name}

%postun systemd-nginx
sed -i 's/^.*User=nginx.*$/User=/' %{_unitdir}/%{name}.service
sed -i 's/^.*Group=nginx.*$/Group=/' %{_unitdir}/%{name}.service
systemctl daemon-reload
chown -R root:root /var/run/%{name}


%clean
%{__rm} -rf %{buildroot}

%post
%systemd_post %{name}.service

%preun
%systemd_preun %{name}.service

%changelog
* Thu Jun 30 2016 Valery Khokhlov <voler88@gmail.com> - 1.1.0-2
- Fix man. Add doc. Move systemd to submodule. Add nginx submodule.

* Tue Apr 22 2014 Justin Zhang <schnell18[AT]gmail.com> - 1.1.0-1
- version 1.1.0
- Create RPM spec file for the fcgiwrap
